// FILENAME:	DM_City_on_the_Edge.cs
//
// AUTHORS:  	Chupie Doll & Youth in Asia
//------------------------------------------------------------------------------

$missionName = "DM_Psychotic_Night";

exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");

$BlueOwner 	= "";
$RedOwner 	= "";
$BluePBKills= 0;
$RedPBKills = 0;
$DELAY 	= 45;
$HEALVAL 	= 7500;
$AMMOVAL 	= 75;
$HP1_RST	= 0;
$HP2_RST	= 0;
$HP3_RST	= 0;
$HP4_RST	= 0;
$AP1_RST	= 0;
$AP2_RST	= 0;
$AP3_RST	= 0;
$AP4_RST	= 0;

function player::onAdd(%this)
{
   say(%this, 0, "Welcome to " @ $missionName @ "! ");
}

function setDefaultMissionOptions()
{
	$server::TeamPlay = false;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;

   // what can the server admin choose for available teams
   $server::disableTeamRed = false;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = true;
}

function onMissionStart()
{
	initGlobalVars();

	marsSounds();
}

function onMissionLoad(){
   cdAudioCycle("Purge", "Terror", "Watching"); 
}

function vehicle::onAdd(%vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);

	%player.name = getHUDName(%vehicleId);
	if(!%player.PBKills) %player.PBKills = 0;
}


// Rules...
//------------------------------------------------------------------------------

function setRules()
{
      %rules = "<tIDMULT_TDM_GAMETYPE>"   @        
               "<tIDMULT_TDM_MAPNAME>"    @
               $missionName             	@
               "\n\n<F2>MAP RULES/OBJECTIVES:\n" 									@
               "<F0>1) This is a two-team TDM map.\n" 								@
               "2) Capture the pillboxes to activate their turrets.\n"						@
		   "   Kills made by turrets will be awarded to the pillbox owner.\n"				@
               "3) The various 'Energy Balls' will heal you, reload you, or both.\n"			@
		   "4) Use the jump-points to leap in and out of the complex.\n"					@
		   "5) Beware the laser fence!\n\n"										@
               "<F2>SERVER RULES/INFORMATION:\n"      								@ 
               "<F0>1) All weapons are LEGAL.\n" 									@
		   "2) Padkilling is LEGAL, particularly if you heal on an enemies pad.\n" 			@
		   "3) Complaining about items 1 or 2 is ILLEGAL!  Deal with it!  Adapt!  Destroy!\n" 	@
		   "4) This map was made by Temujin.  You can download it from his website\n" 		@
 		   "   at http://www6.50megs.com/temujin.  Also at that site is a comprehensive\n" 		@
 		   "   StarSiege training manual and Temujins skin collections.\n\n" 				@
		   "<tIDMULT_TDM_SCORING_1>"  @
               "<tIDMULT_TDM_SCORING_2>"  @
               $killPoints                @
               "<tIDMULT_TDM_SCORING_3>"  @
               "<tIDMULT_TDM_SCORING_4>"  @
               $deathPoints               @
               "<tIDMULT_TDM_SCORING_5>"  @
               "<tIDMULT_TDM_SCORING_6>"  @
               "<tIDMULT_STD_ITEMS>"      @
               "<tIDMULT_STD_HEAL>"       @
               "<tIDMULT_STD_RELOAD_1>"   @
               $PadWaitTime               @
               "<tIDMULT_STD_RELOAD_2>"   @
               "<tIDMULT_STD_ZEN_1>"      @
               $ZenWaitTime               @
               "<tIDMULT_STD_ZEN_2>";
 
   setGameInfo(%rules);      
}

// setup the rules - this has to be called after the definition of setRules
setRules();


// ELECTRIC FENCE...
//------------------------------------------------------------------------------

function Fence::trigger::OnEnter(%this, %object)
{
      damageObject(%object, 50000);
      say("everybody", 0, getHudName(%object) @ " has been zapped by the laser fence!","sfx_electrical_bzzt.WAV");
}

function vehicle::onDestroyed(%destroyed, %destroyer)
{
   if( %destroyed == $BlueOwner ) schedule("neutralizeblue();", 6);
   if( %destroyed == $RedOwner ) schedule("neutralizered();", 6);
	
   %team = getTeam(%destroyer);

   if(getHUDName(%destroyer) == "Pillbox 001") {
	%temp = playerManager::vehicleIdToPlayerNum($BlueOwner);
	%temp.PBKills++;
      say(%temp, 0, "You get credit for the Pillboxes kill!", "C3_targeteliminated.WAV");
	}
   else if(getHUDName(%destroyer) == "Pillbox 002") {
	%temp = playerManager::vehicleIdToPlayerNum($RedOwner);
	%temp.PBKills++;
      say(%temp, 0, "You get credit for the Pillboxes kill!", "C3_targeteliminated.WAV");
	}

   // Give team credit for turret kills.
   if(%team == *IDSTR_TEAM_RED) 	$RedPBKills++;
   else					$BluePBKills++;

   // Taken from DMStdLib.cs 

   // left over from missionStdLib.cs
   vehicle::onDestroyedLog(%destroyed, %destroyer);
   
   // this is weird but %destroyer isn't necessarily a vehicle
   %message = getFancyDeathMessage(getHUDName(%destroyed), getHUDName(%destroyer));
   if(%message != "")
   {
      say( 0, 0, %message);
   }
   
   // enforce the rules
   if($server::TeamPlay == true)
   {
      if((getTeam(%destroyed) == getTeam(%destroyer)) &&
         (%destroyed != %destroyer) ) {
         antiTeamKill(%destroyer);
      }
   }  
}


// SPECIAL FUNCTIONALITY - HEALS
//------------------------------------------------------------------------------

function SinkHeal(%object, %vehicle)
{
      %player = playerManager::vehicleIdToPlayerNum(%vehicle);
      say(%player, 0, "<f4>The healpack repairs you.<f0>", "Plasma3.WAV");

	healObject(%vehicle, $HEALVAL);

	%x = getPosition(%object,x);
	%y = getPosition(%object,y);
	%z = getPosition(%object,z) - 100;
	
      setPosition(%object, %x, %y, %z);
}

function RaiseHeal(%object)
{
	%x = getPosition(%object,x);
	%y = getPosition(%object,y);
	%z = getPosition(%object,z) + 100;
	
      setPosition(%object, %x, %y, %z);
}

function Heal1::trigger::OnEnter(%this, %object)
{
	if($HP1_RST) return;

	$HP1_RST = 1;

	SinkHeal("MissionGroup\\center\\specials\\HP1", %object);
	schedule("RaiseHeal1();", $DELAY);
}

function RaiseHeal1() 
{
	RaiseHeal("MissionGroup\\center\\specials\\HP1");
	$HP1_RST = 0;
}

function Heal2::trigger::OnEnter(%this, %object)
{
	if($HP2_RST) return;

	$HP2_RST = 1;

	SinkHeal("MissionGroup\\center\\specials\\HP2", %object);
	schedule("RaiseHeal2();", $DELAY);
}

function RaiseHeal2() 
{
	RaiseHeal("MissionGroup\\center\\specials\\HP2");
	$HP2_RST = 0;
}

function Heal3::trigger::OnEnter(%this, %object)
{
	if($HP3_RST) return;

	$HP3_RST = 1;

	SinkHeal("MissionGroup\\center\\specials\\HP3", %object);
	schedule("RaiseHeal3();", $DELAY);
}

function RaiseHeal3() 
{
	RaiseHeal("MissionGroup\\center\\specials\\HP3");
	$HP3_RST = 0;
}

function Heal4::trigger::OnEnter(%this, %object)
{
	if($HP4_RST) return;

	$HP4_RST = 1;

	SinkHeal("MissionGroup\\center\\specials\\HP4", %object);
	schedule("RaiseHeal4();", $DELAY);
}

function RaiseHeal4() 
{
	RaiseHeal("MissionGroup\\center\\specials\\HP4");
	$HP4_RST = 0;
}


// SPECIAL FUNCTIONALITY - AMMO
//------------------------------------------------------------------------------

function SinkAmmo(%object, %vehicle)
{
      %player = playerManager::vehicleIdToPlayerNum(%vehicle);
      say(%player, 0, "<f2>The ammopack reloads you.<f0>", "sfx_lgb.WAV");

	reloadObject(%vehicle, $AMMOVAL);

	%x = getPosition(%object,x);
	%y = getPosition(%object,y);
	%z = getPosition(%object,z) - 100;
	
      setPosition(%object, %x, %y, %z);
}

function RaiseAmmo(%object)
{
	%x = getPosition(%object,x);
	%y = getPosition(%object,y);
	%z = getPosition(%object,z) + 100;
	
      setPosition(%object, %x, %y, %z, 0, -90);
}

function Ammo1::trigger::OnEnter(%this, %object)
{
	if($AP1_RST) return;

	$AP1_RST = 1;

	SinkAmmo("MissionGroup\\center\\specials\\AP1", %object);
	schedule("RaiseAmmo1();", $DELAY);
}

function RaiseAmmo1() 
{
	RaiseAmmo("MissionGroup\\center\\specials\\AP1");
	$AP1_RST = 0;
}

function Ammo2::trigger::OnEnter(%this, %object)
{
	if($AP2_RST) return;

	$AP2_RST = 1;

	SinkAmmo("MissionGroup\\center\\specials\\AP2", %object);
	schedule("RaiseAmmo2();", $DELAY);
}

function RaiseAmmo2() 
{
	RaiseAmmo("MissionGroup\\center\\specials\\AP2");
	$AP2_RST = 0;
}

function Ammo3::trigger::OnEnter(%this, %object)
{
	if($AP3_RST) return;

	$AP3_RST = 1;

	SinkAmmo("MissionGroup\\center\\specials\\AP3", %object);
	schedule("RaiseAmmo3();", $DELAY);
}

function RaiseAmmo3() 
{
	RaiseAmmo("MissionGroup\\center\\specials\\AP3");
	$AP3_RST = 0;
}

function Ammo4::trigger::OnEnter(%this, %object)
{
	if($AP4_RST) return;

	$AP4_RST = 1;

	SinkAmmo("MissionGroup\\center\\specials\\AP4", %object);
	schedule("RaiseAmmo4();", $DELAY);
}

function RaiseAmmo4() 
{
	RaiseAmmo("MissionGroup\\center\\specials\\AP4");
	$AP4_RST = 0;
}


// SPECIAL FUNCTIONALITY - AMMO
//------------------------------------------------------------------------------

function ZenBall::trigger::OnEnter(%this, %object)
{
      %player = playerManager::vehicleIdToPlayerNum(%object);
      say(%player, 0, "<f1>Zen energy repairs and reloads your vehicle.<f0>", "sfx_machine3.WAV");

	reloadObject(%object, 3*$AMMOVAL);
	healObject(%object, 3*$HEALVAL);
}


// PillBox Functionality (BLUE)
//------------------------------------------------------------------------------

function BluePB::trigger::OnEnter(%this, %object)
{
      %player = playerManager::vehicleIdToPlayerNum(%object);

	if($BlueOwner && %object!= $BlueOwner) {
		say(%player, 0, "You are ejected from the Pillbox!", "sfx_cybrid_alarm.WAV");
		rejectblue(%object);
		return 0;
		}

	$BlueOwner = %object;
      say(%player, 0, "<f4>You take command of the Pillbox:<f1> Turrets activated!<f0>", "sfx_machine2.WAV");

	%team = getTeam(%object);
	healObject("MissionGroup\\bluebase\\PB\\T1",  20*$HEALVAL);
	setTeam("MissionGroup\\bluebase\\PB\\T1", %team);

	healObject("MissionGroup\\bluebase\\PB\\T2",  20*$HEALVAL);
	setTeam("MissionGroup\\bluebase\\PB\\T2", %team);

	healObject("MissionGroup\\bluebase\\PB\\T3",  20*$HEALVALy);
	setTeam("MissionGroup\\bluebase\\PB\\T3", %team);
}

function BluePB::trigger::OnLeave(%this, %object)
{
	if( %object == $BlueOwner ) schedule("neutralizeblue();", 2);

      %player = playerManager::vehicleIdToPlayerNum(%object);
      say(%player, 0, "<f1>Turrets are deactivated.<f0>", "sfx_machine1.WAV");
}

function rejectblue(%object)
{
      %chx = 0 - getPosition(%object,x);
      %chy = -600 - getPosition(%object,y);

	%x = 0 - 3 * %chx;
	%y = -600 - 3 * %chy;
	
      setPosition(%object, %x, %y, 102);
}

function neutralizeblue()
{
	if($BlueOwner == "") return 0;
	$BlueOwner = "";
	setTeam("MissionGroup\\bluebase\\PB\\T1", 0);
	setTeam("MissionGroup\\bluebase\\PB\\T2", 0);
	setTeam("MissionGroup\\bluebase\\PB\\T3", 0);
}


// PillBox Functionality (RED)
//------------------------------------------------------------------------------

function RedPB::trigger::OnEnter(%this, %object)
{
      %player = playerManager::vehicleIdToPlayerNum(%object);

	if($RedOwner && %object!= $RedOwner) {
		say(%player, 0, "You are ejected from the Pillbox!", "sfx_cybrid_alarm.WAV");
		rejectred(%object);
		return 0;
		}

	$RedOwner = %object;
      say(%player, 0, "<f4>You take command of the Pillbox:<f5> Turrets activated!<f0>", "sfx_machine2.WAV");

	%team = getTeam(%object);
	healObject("MissionGroup\\redbase\\PB\\T1",  20*$HEALVAL);
	setTeam("MissionGroup\\redbase\\PB\\T1", %team);

	healObject("MissionGroup\\bluebase\\PB\\T2",  20*$HEALVAL);
	setTeam("MissionGroup\\redbase\\PB\\T2", %team);

	healObject("MissionGroup\\bluebase\\PB\\T3",  20*$HEALVAL);
	setTeam("MissionGroup\\redbase\\PB\\T3", %team);
}

function RedPB::trigger::OnLeave(%this, %object)
{
	if( %object == $RedOwner ) schedule("neutralizered();", 2);

      %player = playerManager::vehicleIdToPlayerNum(%object);
      say(%player, 0, "<f5>Turrets are deactivated.<f0>", "sfx_machine1.WAV");
}

function rejectred(%object)
{
      %chx = 0 - getPosition(%object,x);
      %chy = 600 - getPosition(%object,y);

	%x = 0 - 3 * %chx;
	%y = 600 - 3 * %chy;
	
      setPosition(%object, %x, %y, 102);
}

function neutralizered()
{
	if($RedOwner == "") return 0;
	$RedOwner = "";
	setTeam("MissionGroup\\redbase\\PB\\T1", 0);
	setTeam("MissionGroup\\redbase\\PB\\T2", 0);
	setTeam("MissionGroup\\redbase\\PB\\T3", 0);
}


// Trampoline...
//-----------------------------------------------------------------------------

function JumpBlue::trigger::OnEnter(%this, %object)
{
      %mass = findTrueMass(%object);
      %height = 750 - (5 * %mass);
	%startX = getPosition(%object,x);
	%startY = getPosition(%object,y);

      %player = playerManager::vehicleIdToPlayerNum(%object);

      say(%player, 0, "sfx_had.WAV");
      schedule( "leap("@%object@","@%height@","@%startX@","@%startY@");", 0.2);

	schedule( "RaiseBluePad();", 0.25);
}

function JumpRed::trigger::OnEnter(%this, %object)
{
      %mass = findTrueMass(%object);
      %height = 750 - (5 * %mass);
	%startX = getPosition(%object,x);
	%startY = getPosition(%object,y);

      %player = playerManager::vehicleIdToPlayerNum(%object);

      say(%player, 0, "sfx_had.WAV");
      schedule( "leap("@%object@","@%height@","@%startX@","@%startY@");", 0.2);

	schedule( "RaiseRedPad();", 0.25);
}

function JumpIn::trigger::OnEnter(%this, %object)
{
      %mass = findTrueMass(%object);
      %height = 600 - (3 * %mass);
	%startX = getPosition(%object,x);
	%startY = getPosition(%object,y);

      %player = playerManager::vehicleIdToPlayerNum(%object);

      say(%player, 0, "teleporter.WAV");
      schedule( "leap("@%object@","@%height@","@%startX@","@%startY@");", 0.25);
}

function RaiseBluePad() 
{
	%lift = getObjectId("MissionGroup\\blueBase\\JumpPad");
	RaiseLift(%lift, 120, 140);
}

function RaiseRedPad() 
{
	%lift = getObjectId("MissionGroup\\redBase\\JumpPad");
	RaiseLift(%lift, 102, 113);
}

function RaiseLift(%lift, %start, %stop)
{
	%X = getPosition(%lift,x);
	%Y = getPosition(%lift,y);

	setPosition(%lift, %X, %Y, %stop);

	%dif = %stop - %start;

	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.9*%dif) @ ");", 0.1);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.8*%dif) @ ");", 0.2);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.7*%dif) @ ");", 0.3);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.6*%dif) @ ");", 0.4);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.5*%dif) @ ");", 0.5);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.4*%dif) @ ");", 0.6);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.3*%dif) @ ");", 0.7);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.2*%dif) @ ");", 0.8);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ (%start + 0.1*%dif) @ ");", 0.9);
	schedule( "LowerLift(" @ %lift @"," @ %X @ "," @ %Y @ "," @ %start @ ");", 1.0);
}

function LowerLift(%ob, %x, %y, %z)
{
	setPosition(%ob, %x, %y, %z);
}

function leap(%object, %height, %sX, %sY)
{
      //This fakes the 'speed', allows momentum to carry through...
      //change vars are prevented from being between -1 and 1.

	%start = getPosition(%object,z);

	%chX = 3*(getPosition(%object,x) - %sX);
         if(%chX < 1)
            if(%chX > -1) %chX = 1;
	%chY = 3*(getPosition(%object,y) - %sY);
         if(%chY < 1)
            if(%chY > -1) %chY = 1;

	%temp = 0.098 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.1);

	%temp = 0.19 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.2);

	%temp = 0.278 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.3);

	%temp = 0.36 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.4);

	%temp = 0.438 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.5);

	%temp = 0.51 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.6);

	%temp = 0.578 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.7);

	%temp = 0.64 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.8);

	%temp = 0.698 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",0.9);

	%temp = 0.75 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1);

	%temp = 0.798 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.1);

	%temp = 0.84 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.2);

	%temp = 0.878 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.3);

	%temp = 0.91 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.4);

	%temp = 0.938 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.5);	

	%temp = 0.96 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.6);	

	%temp = 0.978 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.7);

	%temp = 0.99 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.8);

	%temp = 0.998 * %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",1.9);

	%temp = %height;
	schedule("addZ("@%object@","@%temp@","@%chX@","@%chY@","@%start@");",2);
}

function addZ(%object, %z, %chX, %chY, %start)
{
	%z += %start;
      %y = getPosition(%object,y) + %chY;
      %x = getPosition(%object,x) + %chX;

	if(%z < (getTerrainHeight( %x, %y ) + 10) )
  	   %z = getTerrainHeight( %x, %y ) + 10;

	setPosition(%object, %x, %y, %z);
}
	
//-----------------------------------------------------------------------------
// Mass Code (thanks to Dungat)...

function findTrueMass(%what)
{
	return (findBaseMass(%what) - getVehicleAvailableMass(%what));
      //getVehicleAvailableMass() gives you the amount of room left, right?
}

function findBaseMass(%what)
{
	%type= getVehicleName(%what);
	if (%type=="Talon") return 30;
	if (%type=="Knight's Talon") return 30;
	if (%type=="Minotaur") return 40;
	if (%type=="Knight's Minotaur") return 40;
	if (%type=="Basilisk") return 50;
	if (%type=="Knight's Basilisk") return 50;
	if (%type=="Apocalpyse") return 60;
	if (%type=="Knight's Apocalypse") return 60;
	if (%type=="Gorgon") return 80;
	if (%type=="Knight's Gorgon") return 80;
	if (%type=="Emancipator") return 40;
	if (%type=="Outrider Emancipator") return 40;
	if (%type=="Olympian") return 75;
	if (%type=="Avenger") return 30;
	if (%type=="Dreadlock") return 45;
	if (%type=="Disrupter") return 55;
	if (%type=="Myrmidon") return 90;
	if (%type=="Paladin") return 60;
	if (%type=="Knight's Disrupter") return 55;
	if (%type=="Knight's Myrmidon") return 90;
	if (%type=="Knight's Paladin") return 60;
	if (%type=="Harabec's Predator") return 60;
	if (%type=="Seeker") return 25;
	if (%type=="Metagen Seeker") return 25;
	if (%type=="Goad") return 35;
	if (%type=="Metagen Goad") return 35;
	if (%type=="Shepherd") return 48;
	if (%type=="Metagen Shepherd") return 48;
	if (%type=="Adjudicator") return 60;
	if (%type=="Platinum Guard Adjudicator") return 60;
	if (%type=="Executioner") return 90;
	if (%type=="Platinum Guard Executioner") return 90;
	if (%type=="Bolo") return 35;
	if (%type=="Recluse") return 40;
	return 0;
}


//------------------------------------------------------------------------------
// scoreboard 

function getPlayerScore(%a)
{
   %p = (getAdjKills(%a)*$killPoints)-(getDeaths(%a)*$deathPoints);
   return (%p);
}

function getAdjKills(%a)
{
   return (getKills(%a) + %a.PBKills);
}

function getTeamScore(%a)
{
   return((getAdjTeamKills(%a) * $killPoints) - (getTeamDeaths(%a) * $deathPoints));
} 

function getAdjTeamKills(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) return (getTeamKills(%team) + $RedPBKills);
   if(%teamname == *IDSTR_TEAM_BLUE) return (getTeamKills(%team) + $BluePBKills);
   else return 0;
}

function initScoreBoard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

   if($server::TeamPlay == "True")	
   {
	   // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_TEAM;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader5 = *IDMULT_SCORE_DEATHS;

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getTeam";
	   $ScoreBoard::PlayerColumnFunction2 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction3 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction4 = "getAdjKills";
	   $ScoreBoard::PlayerColumnFunction5 = "getDeaths";
   }
   else
   {
       // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_DEATHS;

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction2 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction3 = "getAdjKills";
	   $ScoreBoard::PlayerColumnFunction4 = "getDeaths";
   }

   // Team ScoreBoard column headings
   $ScoreBoard::TeamColumnHeader1 = *IDMULT_SCORE_SCORE;
   $ScoreBoard::TeamColumnHeader2 = *IDMULT_SCORE_PLAYERS;
   $ScoreBoard::TeamColumnHeader3 = *IDMULT_SCORE_KILLS;
   $ScoreBoard::TeamColumnHeader4 = *IDMULT_SCORE_DEATHS;

   // Team ScoreBoard column functions
   $ScoreBoard::TeamColumnFunction1 = "getTeamScore";
   $ScoreBoard::TeamColumnFunction2 = "getNumberOfPlayersOnTeam";
   $ScoreBoard::TeamColumnFunction3 = "getAdjTeamKills";
   $ScoreBoard::TeamColumnFunction4 = "getTeamDeaths";

   // tell server to process all the scoreboard definitions defined above
   serverInitScoreBoard();
}
